@@ -454,16 +454,16 @@ ghttp_get_status(ghttp_request *a_request)
     {
       if (a_request->resp->content_length > 0)
 	{
-	  if (a_request->resp->body_len)
-	    l_return.bytes_read = a_request->resp->body_len;
-	  else
-	    l_return.bytes_read = a_request->conn->io_buf_alloc;
+          l_return.bytes_read = a_request->resp->body_len +
+            a_request->conn->io_buf_alloc +
+            a_request->resp->flushed_length;
 	  l_return.bytes_total = a_request->resp->content_length;
 	}
       else
 	{
 	  l_return.bytes_read = a_request->resp->body_len +
-	    a_request->conn->io_buf_alloc;
+	    a_request->conn->io_buf_alloc +
+            a_request->resp->flushed_length;
 	  l_return.bytes_total = -1;
 	}
     }
@@ -475,6 +475,12 @@ ghttp_get_status(ghttp_request *a_request)
   return l_return;
 }
 
+void
+ghttp_flush_response_buffer(ghttp_request *a_request)
+{
+  http_resp_flush(a_request->resp, a_request->conn);
+}
+
 int
 ghttp_close(ghttp_request *a_request)
 {
