@@ -143,6 +143,9 @@ http_req_send(http_req *a_req, http_trans_conn *a_conn)
     }
   /* set the request in the connection buffer */
   http_trans_append_data_to_buf(a_conn, l_request, l_request_len);
+  /* free up the request - we don't need it anymore */
+  free(l_request);
+  l_request = NULL;
   /* set the state */
   a_req->state = http_req_state_sending_request;
  http_req_state_sending_request_jump:
