@@ -50,7 +50,7 @@ typedef enum http_req_state_tag {
   http_req_state_start = 0,
   http_req_state_sending_request,
   http_req_state_sending_headers,
-  http_req_state_sending_body,
+  http_req_state_sending_body
 } http_req_state;
 
 /* same character representations as above. */
