@@ -626,6 +626,29 @@ read_body_chunked(http_resp *a_resp,
   return HTTP_TRANS_DONE;
 }
 
+static void
+flush_response_body(http_resp *a_resp,
+                    http_trans_conn *a_conn)
+{
+  if (a_resp->body != NULL) {
+    free(a_resp->body);
+  }
+  a_resp->flushed_length += a_resp->body_len;
+  a_resp->body_len = a_conn->io_buf_alloc;
+  a_resp->body = malloc(a_conn->io_buf_alloc + 1);
+  memset(a_resp->body, 0, a_conn->io_buf_alloc + 1);
+  memcpy(a_resp->body, a_conn->io_buf, a_conn->io_buf_alloc);
+  /* clean the buffer */
+  http_trans_buf_reset(a_conn);
+}
+
+void
+http_resp_flush(http_resp *a_resp,
+                http_trans_conn *a_conn)
+{
+  flush_response_body(a_resp, a_conn);
+}
+
 static int
 read_body_content_length(http_resp *a_resp,
 			 http_req *a_req,
@@ -640,7 +663,7 @@ read_body_content_length(http_resp *a_resp,
     return HTTP_TRANS_DONE;
 
   /* find out how much more we have to read */
-  l_left_to_read = l_len - a_conn->io_buf_alloc;
+  l_left_to_read = l_len - a_conn->io_buf_alloc - a_resp->flushed_length - a_resp->body_len;
   /* set the variables */
   a_conn->io_buf_io_left = l_left_to_read;
   a_conn->io_buf_io_done = 0;
@@ -660,12 +683,7 @@ read_body_content_length(http_resp *a_resp,
 	return HTTP_TRANS_ERR;
     }
   /* write it into the body */
-  a_resp->body_len = l_len;
-  a_resp->body = malloc(l_len);
-  memset(a_resp->body, 0, l_len);
-  memcpy(a_resp->body, a_conn->io_buf, l_len);
-  /* clean the buffer */
-  http_trans_buf_reset(a_conn);
+  flush_response_body (a_resp, a_conn);
   return HTTP_TRANS_DONE;
 }
 
@@ -688,11 +706,6 @@ read_body_standard(http_resp *a_resp,
   if (l_rv == HTTP_TRANS_ERR)
     return HTTP_TRANS_ERR;
 
-  a_resp->body_len = a_conn->io_buf_alloc;
-  a_resp->body = malloc(a_conn->io_buf_alloc + 1);
-  memset(a_resp->body, 0, a_conn->io_buf_alloc + 1);
-  memcpy(a_resp->body, a_conn->io_buf, a_conn->io_buf_alloc);
-  /* clean the buffer */
-  http_trans_buf_reset(a_conn);
+  flush_response_body(a_resp, a_conn);
   return HTTP_TRANS_DONE;
 }
