@@ -57,6 +57,7 @@ typedef struct http_resp_tag
   char                                *body;
   int                                  body_len;
   int                                  content_length;
+  int                                  flushed_length;
   http_resp_header_state               header_state;
   http_resp_body_state                 body_state;
 } http_resp;
@@ -75,4 +76,8 @@ http_resp_read_body(http_resp *a_resp,
 int
 http_resp_read_headers(http_resp *a_resp, http_trans_conn *a_conn);
 
+void
+http_resp_flush(http_resp *a_resp,
+                http_trans_conn *a_conn);
+
 #endif /* HTTP_RESP_H */
