@@ -60,7 +60,7 @@ http_uri_parse(char *a_string,
     a_uri->proto[l_start_string - a_string] = '\0';
   }
   /* check to make sure it starts with "http://" */
-  if (memcmp(l_start_string, "://", 3) != 0)
+  if (strncmp(l_start_string, "://", 3) != 0)
     goto ec;
   /* start at the beginning of the string */
   l_start_string = l_end_string = &l_start_string[3];
